@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | PHP Version 5                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2013 The PHP Group                                |
+   | Copyright (c) 1997-2014 The PHP Group                                |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -48,7 +48,7 @@ ZEND_BEGIN_ARG_INFO_EX(arginfo_event_base_loopexit, 0, 0, 0)
 ZEND_END_ARG_INFO();
 
 ZEND_BEGIN_ARG_INFO_EX(arginfo_event__construct, 0, 0, 4)
-	ZEND_ARG_INFO(0, base)
+	ZEND_ARG_INFO(1, base)
 	ZEND_ARG_INFO(0, fd)
 	ZEND_ARG_INFO(0, what)
 	ZEND_ARG_INFO(0, cb)
@@ -56,7 +56,7 @@ ZEND_BEGIN_ARG_INFO_EX(arginfo_event__construct, 0, 0, 4)
 ZEND_END_ARG_INFO();
 
 ZEND_BEGIN_ARG_INFO_EX(arginfo_event_set, 0, 0, 2)
-	ZEND_ARG_INFO(0, base)
+	ZEND_ARG_INFO(1, base)
 	ZEND_ARG_INFO(0, fd)
 	ZEND_ARG_INFO(0, what)
 	ZEND_ARG_INFO(0, cb)
@@ -84,20 +84,20 @@ ZEND_BEGIN_ARG_INFO_EX(arginfo_event_pending, 0, 0, 1)
 ZEND_END_ARG_INFO();
 
 ZEND_BEGIN_ARG_INFO_EX(arginfo_evtimer_new, 0, 0, 2)
-	ZEND_ARG_INFO(0, base)
+	ZEND_ARG_INFO(1, base)
 	ZEND_ARG_INFO(0, cb)
 	ZEND_ARG_INFO(0, arg)
 ZEND_END_ARG_INFO();
 
 ZEND_BEGIN_ARG_INFO_EX(arginfo_evtimer_set, 0, 0, 2)
-	ZEND_ARG_INFO(0, base)
+	ZEND_ARG_INFO(1, base)
 	ZEND_ARG_INFO(0, cb)
 	ZEND_ARG_INFO(0, arg)
 ZEND_END_ARG_INFO();
 
 
 ZEND_BEGIN_ARG_INFO_EX(arginfo_evsignal_new, 0, 0, 3)
-	ZEND_ARG_INFO(0, base)
+	ZEND_ARG_INFO(1, base)
 	ZEND_ARG_INFO(0, signum)
 	ZEND_ARG_INFO(0, cb)
 	ZEND_ARG_INFO(0, arg)
@@ -118,7 +118,7 @@ ZEND_BEGIN_ARG_INFO_EX(arginfo_bufferevent__events, 0, 0, 1)
 ZEND_END_ARG_INFO();
 
 ZEND_BEGIN_ARG_INFO_EX(arginfo_bufferevent__construct, 0, 0, 1)
-	ZEND_ARG_INFO(0, base)
+	ZEND_ARG_INFO(1, base)
 	ZEND_ARG_INFO(0, socket)
 	ZEND_ARG_INFO(0, options)
 	ZEND_ARG_INFO(0, readcb)
@@ -167,7 +167,7 @@ ZEND_BEGIN_ARG_INFO_EX(arginfo_bufferevent_read, 0, 0, 1)
 ZEND_END_ARG_INFO();
 
 ZEND_BEGIN_ARG_INFO_EX(arginfo_bufferevent_pair_new, 0, 0, 1)
-	ZEND_ARG_INFO(0, base)
+	ZEND_ARG_INFO(1, base)
 	ZEND_ARG_INFO(0, options)
 ZEND_END_ARG_INFO();
 
@@ -182,7 +182,7 @@ ZEND_END_ARG_INFO();
 
 #ifdef HAVE_EVENT_OPENSSL_LIB
 ZEND_BEGIN_ARG_INFO_EX(arginfo_bufferevent_ssl_filter, 0, 0, 4)
-	ZEND_ARG_INFO(0, base)
+	ZEND_ARG_INFO(1, base)
 	ZEND_ARG_INFO(0, underlying)
 	ZEND_ARG_INFO(0, ctx)
 	ZEND_ARG_INFO(0, state)
@@ -190,7 +190,7 @@ ZEND_BEGIN_ARG_INFO_EX(arginfo_bufferevent_ssl_filter, 0, 0, 4)
 ZEND_END_ARG_INFO();
 
 ZEND_BEGIN_ARG_INFO_EX(arginfo_bufferevent_ssl_socket, 0, 0, 4)
-	ZEND_ARG_INFO(0, base)
+	ZEND_ARG_INFO(1, base)
 	ZEND_ARG_INFO(0, socket)
 	ZEND_ARG_INFO(0, ctx)
 	ZEND_ARG_INFO(0, state)
@@ -271,7 +271,7 @@ ZEND_END_ARG_INFO();
 
 
 ZEND_BEGIN_ARG_INFO_EX(arginfo_event_evhttp_connection__construct, 0, 0, 4)
-	ZEND_ARG_INFO(0, base)
+	ZEND_ARG_INFO(1, base)
 	ZEND_ARG_INFO(0, dns_base)
 	ZEND_ARG_INFO(0, address)
 	ZEND_ARG_INFO(0, port)
@@ -303,7 +303,7 @@ ZEND_BEGIN_ARG_INFO_EX(arginfo_event_evhttp_connection_set_retries, 0, 0, 1)
 ZEND_END_ARG_INFO();
 
 ZEND_BEGIN_ARG_INFO_EX(arginfo_event_http__construct, 0, 0, 1)
-	ZEND_ARG_INFO(0, base)
+	ZEND_ARG_INFO(1, base)
 ZEND_END_ARG_INFO();
 
 
@@ -417,7 +417,7 @@ ZEND_END_ARG_INFO();
 /* {{{ ARGINFO for extra API */
 
 ZEND_BEGIN_ARG_INFO_EX(arginfo_evdns__construct, 0, 0, 2)
-	ZEND_ARG_INFO(0, base)
+	ZEND_ARG_INFO(1, base)
 	ZEND_ARG_INFO(0, initialize)
 ZEND_END_ARG_INFO();
 
@@ -449,7 +449,7 @@ ZEND_END_ARG_INFO();
 
 
 ZEND_BEGIN_ARG_INFO_EX(arginfo_evconnlistener__construct, 0, 0, 6)
-	ZEND_ARG_INFO(0, base)
+	ZEND_ARG_INFO(1, base)
 	ZEND_ARG_INFO(0, cb)
 	ZEND_ARG_INFO(0, data)
 	ZEND_ARG_INFO(0, flags)
@@ -458,7 +458,7 @@ ZEND_BEGIN_ARG_INFO_EX(arginfo_evconnlistener__construct, 0, 0, 6)
 ZEND_END_ARG_INFO();
 
 ZEND_BEGIN_ARG_INFO_EX(arginfo_evconnlistener_new_bind, 0, 0, 5)
-	ZEND_ARG_INFO(0, base)
+	ZEND_ARG_INFO(1, base)
 	ZEND_ARG_INFO(0, cb)
 	ZEND_ARG_INFO(0, data)
 	ZEND_ARG_INFO(0, flags)
@@ -565,7 +565,7 @@ const zend_function_entry php_event_bevent_ce_functions[] = {/* {{{ */
 	PHP_ME(EventBufferEvent, writeBuffer,       arginfo_bufferevent_write_buffer,  ZEND_ACC_PUBLIC)
 	PHP_ME(EventBufferEvent, read,              arginfo_bufferevent_read,          ZEND_ACC_PUBLIC)
 	PHP_ME(EventBufferEvent, readBuffer,        arginfo_bufferevent_write_buffer,  ZEND_ACC_PUBLIC)
-	PHP_ME(EventBufferEvent, createPair,        arginfo_bufferevent_pair_new,      ZEND_ACC_PUBLIC)
+	PHP_ME(EventBufferEvent, createPair,        arginfo_bufferevent_pair_new,      ZEND_ACC_PUBLIC | ZEND_ACC_STATIC)
 	PHP_ME(EventBufferEvent, setPriority,       arginfo_bufferevent_priority_set,  ZEND_ACC_PUBLIC)
 	PHP_ME(EventBufferEvent, setTimeouts,       arginfo_bufferevent_set_timeouts,  ZEND_ACC_PUBLIC)
 #ifdef HAVE_EVENT_OPENSSL_LIB
